
class PaymentInstrumentType():
    PayPalAccount = "paypal_account"
    EuropeBankAccount = "europe_bank_account"
    CreditCard = "credit_card"
    CoinbaseAccount = "coinbase_account"
    ApplePayCard = "apple_pay_card"
    AndroidPayCard = "android_pay_card"
